@@ -18,6 +18,7 @@ import subprocess
 import sys
 import glob
 
+import six
 from six.moves import urllib
 import toolz as tz
 import yaml
@@ -39,7 +40,7 @@ REMOTES = {
 SUPPORTED_GENOMES = ["GRCh37", "hg19", "hg38", "hg38-noalt", "mm10", "mm9",
                      "rn6", "rn5", "canFam3", "dm3", "galGal4", "phix",
                      "pseudomonas_aeruginosa_ucbpp_pa14", "sacCer3", "TAIR10",
-                     "WBcel235", "xenTro3", "GRCz10", "GRCz11", "Sscrofa11.1"]
+                     "WBcel235", "xenTro3", "GRCz10", "GRCz11", "Sscrofa11.1", "BDGP6"]
 TARBALL_DIRECTORIES = ["bwa", "rtg", "hisat2"]
 SUPPORTED_INDEXES = TARBALL_DIRECTORIES + ["bbmap", "bowtie", "bowtie2", "minimap2", "novoalign", "twobit",
                                            "snap", "star", "seq"]
@@ -191,10 +192,10 @@ def _install_container_bcbio_system(datadir):
     expose_file = os.path.join(datadir, "galaxy", "bcbio_system.yaml")
     expose = set(["memory", "cores", "jvm_opts"])
     with open(base_file) as in_handle:
-        config = yaml.load(in_handle)
+        config = yaml.safe_load(in_handle)
     if os.path.exists(expose_file):
         with open(expose_file) as in_handle:
-            expose_config = yaml.load(in_handle)
+            expose_config = yaml.safe_load(in_handle)
     else:
         expose_config = {"resources": {}}
     for pname, vals in config["resources"].items():
@@ -214,21 +215,6 @@ def _get_conda_bin():
     if os.path.exists(conda_bin):
         return conda_bin
 
-def _default_deploy_args(args):
-    """Standard install arguments for CloudBioLinux.
-
-    Avoid using sudo and keep an installation isolated if running as the root user.
-    """
-    return {"flavor": "ngs_pipeline_minimal",
-            "vm_provider": "novm",
-            "hostname": "localhost",
-            "fabricrc_overrides": {"edition": "minimal",
-                                   "use_sudo": False,
-                                   "keep_isolated": args.isolate or os.geteuid() == 0,
-                                   "conda_cmd": _get_conda_bin(),
-                                   "distribution": args.distribution or "__auto__",
-                                   "dist_name": "__auto__"}}
-
 def _check_for_conda_problems():
     """Identify post-install conda problems and fix.
 
@@ -236,7 +222,7 @@ def _check_for_conda_problems():
     """
     conda_bin = _get_conda_bin()
     channels = _get_conda_channels(conda_bin)
-    lib_dir = os.path.join(os.path.dirname(conda_bin), os.pardir, "iib")
+    lib_dir = os.path.join(os.path.dirname(conda_bin), os.pardir, "lib")
     for l in ["libgomp.so.1", "libquadmath.so"]:
         if not os.path.exists(os.path.join(lib_dir, l)):
             subprocess.check_call([conda_bin, "install", "-f", "--yes"] + channels + ["libgcc-ng"])
@@ -245,12 +231,13 @@ def _update_bcbiovm():
     """Update or install a local bcbiovm install with tools and dependencies.
     """
     print("## CWL support with bcbio-vm")
-    conda_bin, env_name = _add_environment("bcbiovm", "python=2")
+    python_env = "python=3"
+    conda_bin, env_name = _add_environment("bcbiovm", python_env)
     channels = _get_conda_channels(conda_bin)
     base_cmd = [conda_bin, "install", "--yes", "--name", env_name] + channels
-    subprocess.check_call(base_cmd + ["bcbio-nextgen"])
+    subprocess.check_call(base_cmd + [python_env, "nomkl", "bcbio-nextgen"])
     extra_uptodate = ["cromwell"]
-    subprocess.check_call(base_cmd + ["bcbio-nextgen-vm"] + extra_uptodate)
+    subprocess.check_call(base_cmd + [python_env, "bcbio-nextgen-vm"] + extra_uptodate)
 
 def _get_envs(conda_bin):
     info = json.loads(subprocess.check_output("{conda_bin} info --envs --json".format(**locals()), shell=True))
@@ -272,7 +259,7 @@ def _get_conda_channels(conda_bin):
     """
     channels = ["bioconda", "conda-forge"]
     out = []
-    config = yaml.load(subprocess.check_output([conda_bin, "config", "--show"]))
+    config = yaml.safe_load(subprocess.check_output([conda_bin, "config", "--show"]))
     for c in channels:
         present = False
         for orig_c in config.get("channels") or []:
@@ -346,29 +333,23 @@ def get_gemini_dir(data=None):
 def upgrade_bcbio_data(args, remotes):
     """Upgrade required genome data files in place.
     """
-    from fabric.api import env
     if hasattr(args, "datadir") and args.datadir and os.path.exists(args.datadir):
         data_dir = args.datadir
     else:
         data_dir = _get_data_dir()
-    s = _default_deploy_args(args)
-    s["actions"] = ["setup_biodata"]
     tooldir = args.tooldir or get_defaults().get("tooldir")
-    if tooldir:
-        s["fabricrc_overrides"]["system_install"] = tooldir
-    s["fabricrc_overrides"]["data_files"] = data_dir
-    s["fabricrc_overrides"]["galaxy_home"] = os.path.join(data_dir, "galaxy")
+    galaxy_home = os.path.join(data_dir, "galaxy")
     cbl = get_cloudbiolinux(remotes)
-    s["genomes"] = _get_biodata(cbl["biodata"], args)
+    tool_data_table_conf_file = os.path.join(cbl["dir"], "installed_files", "tool_data_table_conf.xml")
+    genome_opts = _get_biodata(cbl["biodata"], args)
     sys.path.insert(0, cbl["dir"])
-    env.cores = args.cores
-    cbl_deploy = __import__("cloudbio.deploy", fromlist=["deploy"])
-    cbl_deploy.deploy(s)
-    _upgrade_genome_resources(s["fabricrc_overrides"]["galaxy_home"],
-                              remotes["genome_resources"])
-    _upgrade_snpeff_data(s["fabricrc_overrides"]["galaxy_home"], args, remotes)
+    cbl_genomes = __import__("cloudbio.biodata.genomes", fromlist=["genomes"])
+    cbl_genomes.install_data_local(genome_opts, tooldir, data_dir, galaxy_home, tool_data_table_conf_file,
+                                   args.cores, ["ggd", "s3", "raw"])
+    _upgrade_genome_resources(galaxy_home, remotes["genome_resources"])
+    _upgrade_snpeff_data(galaxy_home, args, remotes)
     if "vep" in args.datatarget:
-        _upgrade_vep_data(s["fabricrc_overrides"]["galaxy_home"], tooldir)
+        _upgrade_vep_data(galaxy_home, tooldir)
     if "kraken" in args.datatarget:
         _install_kraken_db(_get_data_dir(), args)
     if args.cwl:
@@ -404,8 +385,8 @@ def _upgrade_genome_resources(galaxy_dir, base_url):
             local_file = os.path.join(os.path.dirname(ref_file), os.path.basename(remote_url))
             if os.path.exists(local_file):
                 with open(local_file) as in_handle:
-                    local_config = yaml.load(in_handle)
-                remote_config = yaml.load(r.text)
+                    local_config = yaml.safe_load(in_handle)
+                remote_config = yaml.safe_load(r.text)
                 needs_update = remote_config["version"] > local_config.get("version", 0)
                 if needs_update:
                     shutil.move(local_file, local_file + ".old%s" % local_config.get("version", 0))
@@ -430,7 +411,7 @@ def _upgrade_snpeff_data(galaxy_dir, args, remotes):
         resource_file = os.path.join(os.path.dirname(ref_file), "%s-resources.yaml" % dbkey)
         if os.path.exists(resource_file):
             with open(resource_file) as in_handle:
-                resources = yaml.load(in_handle)
+                resources = yaml.safe_load(in_handle)
             snpeff_db, snpeff_base_dir = effects.get_db({"genome_resources": resources,
                                                          "reference": {"fasta": {"base": ref_file}}})
             if snpeff_db:
@@ -461,7 +442,7 @@ def _is_old_database(db_dir, args):
         pred_file = os.path.join(db_dir, "snpEffectPredictor.bin")
         if not utils.file_exists(pred_file):
             return True
-        with gzip.open(pred_file) as in_handle:
+        with utils.open_gzipsafe(pred_file, is_gz=True) as in_handle:
             version_info = in_handle.readline().strip().split("\t")
         program, version = version_info[:2]
         if not program.lower() == "snpeff" or LooseVersion(snpeff_version) > LooseVersion(version):
@@ -472,7 +453,7 @@ def _get_biodata(base_file, args):
     """Retrieve biodata genome targets customized by install parameters.
     """
     with open(base_file) as in_handle:
-        config = yaml.load(in_handle)
+        config = yaml.safe_load(in_handle)
     config["install_liftover"] = False
     config["genome_indexes"] = args.aligners
     ann_groups = config.pop("annotation_groups", {})
@@ -503,22 +484,15 @@ def upgrade_thirdparty_tools(args, remotes):
 
     Creates a manifest directory with installed programs on the system.
     """
-    s = {"fabricrc_overrides": {"system_install": args.tooldir,
-                                "local_install": os.path.join(args.tooldir, "local_install"),
-                                "distribution": args.distribution,
-                                "conda_cmd": _get_conda_bin(),
-                                "use_sudo": False,
-                                "edition": "minimal"}}
-    s = _default_deploy_args(args)
-    s["actions"] = ["install_biolinux"]
-    s["fabricrc_overrides"]["system_install"] = args.tooldir
-    s["fabricrc_overrides"]["local_install"] = os.path.join(args.tooldir, "local_install")
-    if args.toolconf and os.path.exists(args.toolconf):
-        s["fabricrc_overrides"]["conda_yaml"] = args.toolconf
     cbl = get_cloudbiolinux(remotes)
+    if args.toolconf and os.path.exists(args.toolconf):
+        package_yaml = args.toolconf
+    else:
+        package_yaml = os.path.join(cbl["dir"], "contrib", "flavor",
+                                    "ngs_pipeline_minimal", "packages-conda.yaml")
     sys.path.insert(0, cbl["dir"])
-    cbl_deploy = __import__("cloudbio.deploy", fromlist=["deploy"])
-    cbl_deploy.deploy(s)
+    cbl_conda = __import__("cloudbio.package.conda", fromlist=["conda"])
+    cbl_conda.install_in(_get_conda_bin(), args.tooldir, package_yaml)
     manifest_dir = os.path.join(_get_data_dir(), "manifest")
     print("Creating manifest of installed packages in %s" % manifest_dir)
     cbl_manifest = __import__("cloudbio.manifest", fromlist=["manifest"])
@@ -571,7 +545,7 @@ def _update_manifest(manifest_file, name, version):
     """
     if os.path.exists(manifest_file):
         with open(manifest_file) as in_handle:
-            manifest = yaml.load(in_handle)
+            manifest = yaml.safe_load(in_handle)
     else:
         manifest = {}
     manifest[name] = {"name": name, "version": version}
@@ -585,7 +559,7 @@ def _update_system_file(system_file, name, new_kvs):
         bak_file = system_file + ".bak%s" % datetime.datetime.now().strftime("%Y-%m-%d-%H-%M-%S")
         shutil.copyfile(system_file, bak_file)
         with open(system_file) as in_handle:
-            config = yaml.load(in_handle)
+            config = yaml.safe_load(in_handle)
     else:
         utils.safe_makedir(os.path.dirname(system_file))
         config = {}
@@ -661,7 +635,7 @@ def save_install_defaults(args):
         return
     if utils.file_exists(install_config):
         with open(install_config) as in_handle:
-            cur_config = yaml.load(in_handle)
+            cur_config = yaml.safe_load(in_handle)
     else:
         cur_config = {}
     if args.tooldir:
@@ -695,7 +669,7 @@ def add_install_defaults(args):
         default_args = {}
     else:
         with open(install_config) as in_handle:
-            default_args = yaml.load(in_handle)
+            default_args = yaml.safe_load(in_handle)
     # if we are upgrading to development, also upgrade the tools
     if args.upgrade in ["development"] and (args.tooldir or "tooldir" in default_args):
         args.tools = True
@@ -760,7 +734,7 @@ def get_defaults():
     if install_config is None or not utils.file_exists(install_config):
         return {}
     with open(install_config) as in_handle:
-        return yaml.load(in_handle)
+        return yaml.safe_load(in_handle)
 
 def _check_toolplus(x):
     """Parse options for adding non-standard/commercial tools like GATK and MuTecT.
