@@ -56,12 +56,15 @@ def organize_noalign(data):
     data = utils.to_single_data(data[0])
     work_dir = utils.safe_makedir(os.path.join(dd.get_work_dir(data), "align", dd.get_sample_name(data)))
     work_bam = os.path.join(work_dir, "%s-input.bam" % dd.get_sample_name(data))
-    if data["files"][0].endswith(".cram"):
-        work_bam = cram.to_bam(data["files"][0], work_bam, data)
+    if data.get("files"):
+        if data["files"][0].endswith(".cram"):
+            work_bam = cram.to_bam(data["files"][0], work_bam, data)
+        else:
+            assert data["files"][0].endswith(".bam"), data["files"][0]
+            utils.copy_plus(data["files"][0], work_bam)
+        bam.index(work_bam, data["config"])
     else:
-        assert data["files"][0].endswith(".bam"), data["files"][0]
-        utils.copy_plus(data["files"][0], work_bam)
-    bam.index(work_bam, data["config"])
+        work_bam = None
     data["align_bam"] = work_bam
     return data
 
