@@ -104,7 +104,7 @@ def get_qc_tools(data):
         to_run.append("atropos")
     if "coverage_qc" not in dd.get_tools_off(data):
         to_run.append("samtools")
-    if analysis.startswith(("standard", "variant", "variant2")):
+    if dd.has_variantcalls(data):
         if "coverage_qc" not in dd.get_tools_off(data):
             to_run += ["coverage", "picard"]
         to_run += ["qsignature", "variants"]
@@ -320,7 +320,7 @@ def _other_pipeline_samples(summary_file, cur_samples):
     out = []
     if utils.file_exists(summary_file):
         with open(summary_file) as in_handle:
-            for s in yaml.load(in_handle).get("samples", []):
+            for s in yaml.safe_load(in_handle).get("samples", []):
                 if s["description"] not in cur_descriptions:
                     out.append(s)
     return out
