@@ -35,7 +35,7 @@ ALLOWED_CONTIG_NAME_CHARS = set(list(string.digits) + list(string.ascii_letters)
 ALGORITHM_NOPATH_KEYS = ["variantcaller", "realign", "recalibrate", "peakcaller",
                          "expression_caller", "singlecell_quantifier",
                          "fusion_caller",
-                         "svcaller", "hetcaller", "jointcaller", "tools_off",
+                         "svcaller", "hetcaller", "jointcaller", "tools_off", "tools_on",
                          "mixup_check", "qc", "transcript_assembler"]
 ALGORITHM_FILEONLY_KEYS = ["custom_trim", "vcfanno"]
 # these analysis pipelines use R heavily downstream, and need to have samplenames
@@ -79,7 +79,7 @@ def organize(dirs, config, run_info_yaml, sample_names=None, is_cwl=False,
         item.pop("algorithm", None)
         item = add_reference_resources(item, remote_retriever)
         item["config"]["algorithm"]["qc"] = qcsummary.get_qc_tools(item)
-        item["config"]["algorithm"]["vcfanno"] = vcfanno.find_annotations(item)
+        item["config"]["algorithm"]["vcfanno"] = vcfanno.find_annotations(item, remote_retriever)
         # Create temporary directories and make absolute, expanding environmental variables
         tmp_dir = tz.get_in(["config", "resources", "tmp", "dir"], item)
         if tmp_dir:
@@ -240,7 +240,7 @@ def _fill_validation_targets(data):
     sv_truth = tz.get_in(["config", "algorithm", "svvalidate"], data, {})
     sv_targets = (zip(itertools.repeat("svvalidate"), sv_truth.keys()) if isinstance(sv_truth, dict)
                   else [["svvalidate"]])
-    for vtarget in [list(xs) for xs in [["validate"], ["validate_regions"], ["variant_regions"]] + sv_targets]:
+    for vtarget in [list(xs) for xs in [["validate"], ["validate_regions"], ["variant_regions"]] + list(sv_targets)]:
         val = tz.get_in(["config", "algorithm"] + vtarget, data)
         if val and not os.path.exists(val) and not objectstore.is_remote(val):
             installed_val = os.path.normpath(os.path.join(os.path.dirname(ref_file), os.pardir, "validation", val))
@@ -267,7 +267,7 @@ def _fill_capture_regions(data):
             if len(installed_vals) == 0:
                 if target not in special_targets or not val.startswith(special_targets[target]):
                     raise ValueError("Configuration problem. BED file not found for %s: %s" %
-                                    (target, val))
+                                     (target, val))
             else:
                 assert len(installed_vals) == 1, installed_vals
                 data = tz.update_in(data, ["config", "algorithm", target], lambda x: installed_vals[0])
@@ -288,9 +288,10 @@ def _fill_prioritization_targets(data):
                                                                           val + "*%s" % ext)))
             # Check sv-annotation directory for prioritize gene name lists
             if target == "svprioritize":
-                installed_vals += glob.glob(os.path.join(
-                    os.path.dirname(os.path.realpath(utils.which("simple_sv_annotation.py"))),
-                    "%s*" % os.path.basename(val)))
+                simple_sv_bin = utils.which("simple_sv_annotation.py")
+                if simple_sv_bin:
+                    installed_vals += glob.glob(os.path.join(os.path.dirname(os.path.realpath(simple_sv_bin)),
+                                                             "%s*" % os.path.basename(val)))
             if len(installed_vals) == 0:
                 # some targets can be filled in later
                 if target not in set(["coverage"]):
@@ -550,7 +551,7 @@ ALGORITHM_KEYS = set(["platform", "aligner", "bam_clean", "bam_sort",
                       "disambiguate", "strandedness", "fusion_mode", "fusion_caller",
                       "min_read_length", "coverage_depth_min", "callable_min_size",
                       "min_allele_fraction", "umi_type", "minimum_barcode_depth",
-                      "cellular_barcodes", "vcfanno",
+                      "cellular_barcodes", "vcfanno", "demultiplexed",
                       "sample_barcodes",
                       "exclude_regions", "joint_group_size",
                       "archive", "tools_off", "tools_on", "transcript_assembler",
@@ -562,7 +563,7 @@ ALGORITHM_KEYS = set(["platform", "aligner", "bam_clean", "bam_sort",
                      # back compatibility
                       ["remove_lcr", "coverage_depth_max", "coverage_depth"])
 ALG_ALLOW_BOOLEANS = set(["merge_bamprep", "mark_duplicates", "remove_lcr",
-                          "clinical_reporting", "transcriptome_align",
+                          "demultiplexed", "clinical_reporting", "transcriptome_align",
                           "fusion_mode", "assemble_transcripts", "trim_reads",
                           "recalibrate", "realign", "cwl_reporting", "save_diskspace"])
 ALG_ALLOW_FALSE = set(["aligner", "align_split_size", "bam_clean", "bam_sort",
@@ -662,8 +663,7 @@ def _check_quality_format(items):
                              "is not supported. Supported values are %s."
                              % (SAMPLE_FORMAT.values()))
 
-        fastq_file = next((file for file in item.get('files') or [] if
-                           any([ext for ext in fastq_extensions if ext in file])), None)
+        fastq_file = next((f for f in item.get("files") or [] if f.endswith(tuple(fastq_extensions))), None)
 
         if fastq_file and specified_format and not objectstore.is_remote(fastq_file):
             fastq_format = _detect_fastq_format(fastq_file)
@@ -748,7 +748,7 @@ def _check_jointcaller(data):
     problem = [x for x in cs if x not in allowed]
     if len(problem) > 0:
         raise ValueError("Unexpected algorithm 'jointcaller' parameter: %s\n"
-                         "Supported options: %s\n" % (problem, sorted(list(allowed))))
+                         "Supported options: %s\n" % (problem, sorted(list(allowed), key=lambda x: x or "")))
 
 def _check_indelcaller(data):
     c = data["algorithm"].get("indelcaller")
@@ -902,7 +902,7 @@ def _run_info_from_yaml(dirs, run_info_yaml, config, sample_names=None,
     """
     validate_yaml(run_info_yaml, run_info_yaml)
     with open(run_info_yaml) as in_handle:
-        loaded = yaml.load(in_handle)
+        loaded = yaml.safe_load(in_handle)
     fc_name, fc_date = None, None
     if dirs.get("flowcell"):
         try:
