@@ -4,6 +4,7 @@ https://github.com/ewels/MultiQC
 """
 import collections
 import glob
+import io
 import json
 import mimetypes
 import os
@@ -56,13 +57,15 @@ def summary(*samples):
                     _create_config_file(out_dir, work_samples)
                     input_list_file = _create_list_file(in_files, file_list)
                     if dd.get_tmp_dir(samples[0]):
-                        export_tmp = "export TMPDIR=%s &&" % dd.get_tmp_dir(samples[0])
+                        export_tmp = "export TMPDIR=%s && " % dd.get_tmp_dir(samples[0])
                     else:
                         export_tmp = ""
+                    locale_export = utils.locale_export()
                     path_export = utils.local_path_export()
                     other_opts = config_utils.get_resources("multiqc", samples[0]["config"]).get("options", [])
                     other_opts = " ".join([str(x) for x in other_opts])
-                    cmd = "{path_export}{export_tmp} {multiqc} -f -l {input_list_file} {other_opts} -o {tx_out}"
+                    cmd = ("{path_export}{export_tmp}{locale_export} "
+                           "{multiqc} -f -l {input_list_file} {other_opts} -o {tx_out}")
                     do.run(cmd.format(**locals()), "Run multiqc")
                     if utils.file_exists(os.path.join(tx_out, "multiqc_report.html")):
                         shutil.move(os.path.join(tx_out, "multiqc_report.html"), out_file)
@@ -93,8 +96,9 @@ def summary(*samples):
                 for indir in ["inputs", "report"]:
                     tarball = os.path.join(out_dir, "multiqc-%s.tar.gz" % (indir))
                     if not utils.file_exists(tarball):
-                        cmd = ["tar", "-czvpf", tarball, os.path.join(out_dir, indir)]
-                        do.run(cmd, "Compress multiqc inputs: %s" % indir)
+                        with utils.chdir(out_dir):
+                            cmd = ["tar", "-czvpf", tarball, indir]
+                            do.run(cmd, "Compress multiqc inputs: %s" % indir)
                     samples[0]["summary"]["multiqc"]["secondary"].append(tarball)
 
     if any([cwlutils.is_cwl_run(d) for d in samples]):
@@ -142,13 +146,13 @@ def _save_uploaded_data_json(samples, data_json_work, out_dir):
     if not upload_path_mapping:
         return data_json_work
 
-    with open(data_json_work) as f:
+    with io.open(data_json_work, encoding="utf-8") as f:
         data = json.load(f, object_pairs_hook=OrderedDict)
     upload_base = samples[0]["upload"]["dir"]
     data = walk_json(data, lambda s: _work_path_to_rel_final_path(s, upload_path_mapping, upload_base))
 
     data_json_final = os.path.join(out_dir, "multiqc_data_final.json")
-    with open(data_json_final, "w") as f:
+    with io.open(data_json_final, "w", encoding="utf-8") as f:
         json.dump(data, f, indent=4)
     return data_json_final
 
@@ -194,12 +198,25 @@ def _work_path_to_rel_final_path(path, upload_path_mapping, upload_base_dir):
     if not path or not isinstance(path, str):
         return path
     upload_path = None
-    for work_path, final_path in upload_path_mapping.items():
-        if os.path.isfile(work_path) and path == work_path:
-            upload_path = final_path
-        elif os.path.isdir(work_path) and path.startswith(work_path):
-            upload_path = path.replace(work_path, final_path)
-    if upload_path:
+
+    # First, check in the mapping: if it's there is a direct reference and
+    # it's a file, we immediately return it (saves lots of iterations)
+    if upload_path_mapping.get(path) is not None and os.path.isfile(path):
+        upload_path = upload_path_mapping[path]
+    else:
+        # Not a file: check for elements in the mapping that contain
+        # it
+        paths_to_check = [key for key in upload_path_mapping
+                          if path.startswith(key)]
+
+        if paths_to_check:
+            for work_path in paths_to_check:
+                if os.path.isdir(work_path):
+                    final_path = upload_path_mapping[work_path]
+                    upload_path = path.replace(work_path, final_path)
+                    break
+
+    if upload_path is not None:
         return os.path.relpath(upload_path, upload_base_dir)
     else:
         return None
@@ -360,6 +377,7 @@ def _create_config_file(out_dir, samples):
     else:
         module_order.append("bcftools")
     module_order.extend([
+        "salmon",
         "picard",
         "qualimap",
         "snpeff",
