@@ -17,7 +17,8 @@ from distutils.version import LooseVersion
 import bcbio.pipeline.datadict as dd
 from bcbio.pipeline import config_utils
 from bcbio.provenance import do
-from bcbio.utils import (file_exists, safe_makedir, is_gzipped)
+from bcbio import utils
+from bcbio.utils import (file_exists, safe_makedir)
 from bcbio.distributed.transaction import file_transaction
 from bcbio.bam.fastq import open_fastq
 from bcbio.log import logger
@@ -102,6 +103,26 @@ def get_cellular_barcodes(data):
     else:
         return []
 
+def get_sample_barcodes(fn, out_dir):
+    if not fn:
+        logger.error("Sample demultiplexing needs a list of known indexes provided "
+                     "with via the sample_barcodes option in the algorithm section.")
+        sys.exit(1)
+    utils.safe_makedir(out_dir)
+    out_fn = os.path.join(out_dir, "barcodes.csv")
+    with open(fn) as inh:
+        with open(out_fn, 'w') as outh:
+            for line in inh:
+                outh.write("%s\n" % (line.strip().split(",")[0]))
+    return out_fn
+
+def _umis_cmd(data):
+    """Return umis command line argument, with correct python and locale.
+    """
+    return "%s %s %s" % (utils.locale_export(),
+                         utils.get_program_python("umis"),
+                         config_utils.get_program("umis", data["config"], default="umis"))
+
 def umi_transform(data):
     """
     transform each read by identifying the barcode and UMI for each read
@@ -146,7 +167,11 @@ def umi_transform(data):
         split_option = "--separate_cb"
     else:
         split_option = ""
-    umis = config_utils.get_program("umis", data, default="umis")
+    if dd.get_demultiplexed(data):
+        demuxed_option = "--demuxed_cb %s" % dd.get_sample_name(data)
+        split_option = ""
+    else:
+        demuxed_option = ""
     cores = dd.get_num_cores(data)
     # skip transformation if the file already looks transformed
     with open_fastq(fq1) as in_handle:
@@ -154,9 +179,10 @@ def umi_transform(data):
         if "UMI_" in read:
             data["files"] = [out_file]
             return [[data]]
-
+    locale_export = utils.locale_export()
+    umis = _umis_cmd(data)
     cmd = ("{umis} fastqtransform {split_option} {transform_file} "
-           "--cores {cores} "
+           "--cores {cores} {demuxed_option} "
            "{fq1} {fq2} {fq3} {fq4}"
            "| seqtk seq -L 20 - | gzip > {tx_out_file}")
     message = ("Inserting UMI and barcode information into the read name of %s"
@@ -167,6 +193,9 @@ def umi_transform(data):
     return [[data]]
 
 def filter_barcodes(data):
+    # if data was pre-demultiplexed, there is no need to filter the barcodes
+    if dd.get_demultiplexed(data):
+        return [[data]]
     fq1 = dd.get_input_sequence_files(data)[0]
     umi_dir = os.path.join(dd.get_work_dir(data), "umis")
     correction = dd.get_cellular_barcode_correction(data)
@@ -194,6 +223,7 @@ def filter_barcodes(data):
         return [[data]]
 
     ncores = dd.get_num_cores(data)
+    umis = _umis_cmd(data)
     cmd = "{umis} cb_filter --cores {ncores} "
     if bc1:
         cmd += "--bc1 {bc1} "
@@ -204,13 +234,12 @@ def filter_barcodes(data):
     if bc3:
         cmd += "--bc3 {bc3} "
 
-    fq1_cmd = "{fq1} " if not is_gzipped(fq1) else "<(gzip -cd {fq1}) "
+    fq1_cmd = "{fq1} "
     fq1_cmd = fq1_cmd.format(fq1=fq1)
-    cmd += "{fq1_cmd} | gzip > {tx_out_file}"
+    cmd += "{fq1_cmd} | gzip -c > {tx_out_file}"
 
     sample_dir = os.path.join(umi_dir, dd.get_sample_name(data))
     safe_makedir(sample_dir)
-    umis = config_utils.get_program("umis", data, default="umis")
     with file_transaction(out_file) as tx_out_file:
         message = "Filtering by cellular barcode."
         do.run(cmd.format(**locals()), message)
@@ -221,11 +250,11 @@ def barcode_histogram(data):
     fq1 = dd.get_input_sequence_files(data)[0]
     umi_dir = os.path.join(dd.get_work_dir(data), "umis")
     sample_dir = os.path.join(umi_dir, dd.get_sample_name(data))
-    umis = config_utils.get_program("umis", data, default="umis")
     safe_makedir(sample_dir)
     out_file = os.path.join(sample_dir, "cb-histogram.txt")
     filtered_out_file = os.path.join(sample_dir, "cb-histogram-filtered.txt")
     fq1_cmd = fq1
+    umis = _umis_cmd(data)
     cmd = "{umis} cb_histogram {fq1_cmd} > {tx_out_file}"
     if not file_exists(out_file):
         with file_transaction(out_file) as tx_out_file:
@@ -233,7 +262,8 @@ def barcode_histogram(data):
             do.run(cmd.format(**locals()), message)
     cutoff = dd.get_minimum_barcode_depth(data)
     filter_barcode_histogram(filtered_out_file, out_file, cutoff)
-    return [[data]]
+    newdata = dd.set_histogram_counts(data, filtered_out_file)
+    return [[newdata]]
 
 def tagcount(data):
     bam = dd.get_transcriptome_bam(data)
@@ -244,22 +274,25 @@ def tagcount(data):
     if file_exists(out_file):
         data = dd.set_count_file(data, out_file)
         return [[data]]
-    umis = config_utils.get_program("umis", data, default="umis")
     safe_makedir(sample_dir)
     cutoff = dd.get_minimum_barcode_depth(data)
     cb_histogram = os.path.join(sample_dir, "cb-histogram.txt")
     positional = "--positional" if dd.get_positional_umi(data, False) else ""
-    gtf_file  = dd.get_transcriptome_gtf(data, None)
+    if use_installed_transcriptome(data):
+        gtf_file = dd.get_gtf_file(data)
+    else:
+        gtf_file  = dd.get_transcriptome_gtf(data, None)
 
     if gtf_file:
         gene_map_file = os.path.join(dd.get_work_dir(data), "annotation",
-                                     os.path.splitext(gtf_file)[0] + "-tx2gene.tsv")
+                                     os.path.basename(os.path.splitext(gtf_file)[0]) + "-tx2gene.tsv")
         gene_map_file = gtf.tx2genefile(gtf_file, gene_map_file, tsv=True)
         gene_map_flag = " --genemap {0} ".format(gene_map_file)
     else:
         gene_map_flag = ""
 
     message = "Counting alignments of transcripts in %s." % bam
+    umis = _umis_cmd(data)
     cmd = ("{umis} fasttagcount --cb_cutoff {cutoff} "
            "{gene_map_flag} "
            "{positional} "
@@ -305,7 +338,7 @@ def convert_to_kallisto(data):
     work_dir = dd.get_work_dir(data)
     kallisto_dir = os.path.join(work_dir, "kallisto", samplename, "fastq")
     out_file = os.path.join(kallisto_dir, "barcodes.batch")
-    umis = config_utils.get_program("umis", dd.get_config(data))
+    umis = _umis_cmd(data)
     if file_exists(out_file):
         return out_file
     if dd.get_minimum_barcode_depth(data):
@@ -327,6 +360,10 @@ def demultiplex_samples(data):
     """
     demultiplex a fastqtransformed FASTQ file into separate sample barcode files
     """
+    work_dir = os.path.join(dd.get_work_dir(data), "umis")
+    sample_dir = os.path.join(work_dir, dd.get_sample_name(data))
+    demulti_dir = os.path.join(sample_dir, "demultiplexed")
+
     files = data["files"]
     if len(files) == 2:
         logger.error("Sample demultiplexing doesn't handle paired-end reads, but "
@@ -339,18 +376,12 @@ def demultiplex_samples(data):
         read = next(in_handle)
         if "SAMPLE_" not in read:
             return [[data]]
-    bcfile = dd.get_sample_barcodes(data)
-    if not bcfile:
-        logger.error("Sample demultiplexing needs a list of known indexes provided "
-                     "with via the sample_barcodes option in the algorithm section.")
-        sys.exit(1)
-    work_dir = os.path.join(dd.get_work_dir(data), "umis")
-    sample_dir = os.path.join(work_dir, dd.get_sample_name(data))
-    demulti_dir = os.path.join(sample_dir, "demultiplexed")
+
+    bcfile = get_sample_barcodes(dd.get_sample_barcodes(data), sample_dir)
     demultiplexed = glob.glob(os.path.join(demulti_dir, "*.fq*"))
     if demultiplexed:
         return [split_demultiplexed_sampledata(data, demultiplexed)]
-    umis = config_utils.get_program("umis", data, default="umis")
+    umis = _umis_cmd(data)
     cmd = ("{umis} demultiplex_samples --nedit 1 --barcodes {bcfile} "
            "--out_dir {tx_dir} {fq1}")
     msg = "Demultiplexing {fq1}."
@@ -380,6 +411,7 @@ def split_demultiplexed_sampledata(data, demultiplexed):
 def concatenate_sparse_counts(*samples):
     samples = concatenate_sparse_matrices(samples, deduped=True)
     samples = concatenate_sparse_matrices(samples, deduped=False)
+    samples = concatenate_cb_histograms(samples)
     return samples
 
 def concatenate_sparse_matrices(samples, deduped=True):
@@ -422,11 +454,30 @@ def concatenate_sparse_matrices(samples, deduped=True):
         return newsamples
     return samples
 
+def concatenate_cb_histograms(samples):
+    work_dir = dd.get_in_samples(samples, dd.get_work_dir)
+    umi_dir = os.path.join(work_dir, "umis")
+    out_file = os.path.join(umi_dir, "cb-histogram.txt")
+
+    files = [dd.get_histogram_counts(data) for data in
+            dd.sample_data_iterator(samples)
+            if dd.get_histogram_counts(data)]
+    files = " ".join(files)
+    cmd = "cat {files} > {out_file}"
+    if not file_exists(out_file):
+        with file_transaction(out_file) as tx_out_file:
+            message = "Concat cellular barcode histograms: %s." % files
+            do.run(cmd.format(**locals()), message)
+    newsamples = []
+    for data in dd.sample_data_iterator(samples):
+        newsamples.append([dd.set_combined_histogram(data, out_file)])
+    return newsamples
+
 def version(data):
-    umis_cmd = config_utils.get_program("umis", data, default="umis")
-    version_cmd = [umis_cmd, "version"]
+    umis = _umis_cmd(data)
+    version_cmd = "%s version" % umis
     try:
-        output = subprocess.check_output(version_cmd).decode().strip()
+        output = subprocess.check_output(version_cmd, shell=True).decode().strip()
     except:
         output = None
     return output
@@ -461,3 +512,11 @@ def is_transformed(fastq):
             if "UMI_" in line:
                 return True
     return False
+
+def use_installed_transcriptome(data):
+    user_fa = dd.get_transcriptome_fasta(data)
+    user_gtf = dd.get_transcriptome_gtf(data)
+    if not user_fa and not user_gtf:
+        return True
+    else:
+        return False
