@@ -24,31 +24,19 @@ from bcbio.variation.coverage import regions_coverage
 from bcbio.variation import bedutils, population, vcfutils
 
 
-def precall(items):
+def precall(data):
     """Perform initial pre-calling steps -- coverage calcuation by sample.
 
-    Use sambamba to call average region coverage in regions, and convert into a correct format.
+    Use mosdepth to call average region coverage in regions, and convert
+    into seq2c format.
     """
-    items = [utils.to_single_data(x) for x in items]
-    assert len(items) == 1, "Expect one item to Seq2C coverage calculation"
-    data = items[0]
-    # sv_bed could specify a smaller region than variant coverage, so avoid
-    # this sanity check
-    # assert dd.get_coverage_interval(data) != "genome", "Seq2C only for amplicon and exome sequencing"
-
-    assert "seq2c_bed_ready" in data["config"]["algorithm"], "Error: svregions or variant_regions BED file required for Seq2C"
-
-    bed_file = data["config"]["algorithm"]["seq2c_bed_ready"]
+    data = utils.to_single_data(data)
+    bed_file = tz.get_in(["config", "algorithm", "seq2c_bed_ready"], data)
+    if not bed_file:
+        raise ValueError("Error: svregions or variant_regions BED file required for Seq2C")
     sample_name = dd.get_sample_name(data)
-
     work_dir = _sv_workdir(data)
-    cov_file = _calculate_coverage(data, work_dir, bed_file, sample_name)
-
-    if "sv" not in data:
-        data["sv"] = []
-    data["sv"].append({"variantcaller": "seq2c",
-                       "coverage": cov_file})
-    return [data]
+    return _calculate_coverage(data, work_dir, bed_file, sample_name)
 
 def run(items):
     """Normalization and log2 ratio calculation plus CNV calling for full cohort.
@@ -61,10 +49,17 @@ def run(items):
     items = [utils.to_single_data(x) for x in items]
     work_dir = _sv_workdir(items[0])
 
-    coverage_file = _combine_coverages(items, work_dir)
-    read_mapping_file = _calculate_mapping_reads(items, work_dir)
-
-    normal_names = [dd.get_sample_name(x) for x in items if population.get_affected_status(x) == 1]
+    input_backs = list(set(filter(lambda x: x is not None,
+                                  [dd.get_background_cnv_reference(d, "seq2c") for d in items])))
+    coverage_file = _combine_coverages(items, work_dir, input_backs)
+    read_mapping_file = _calculate_mapping_reads(items, work_dir, input_backs)
+    normal_names = []
+    if input_backs:
+        with open(input_backs[0]) as in_handle:
+            for line in in_handle:
+                if len(line.split()) == 2:
+                    normal_names.append(line.split()[0])
+    normal_names += [dd.get_sample_name(x) for x in items if population.get_affected_status(x) == 1]
     seq2c_calls_file = _call_cnv(items, work_dir, read_mapping_file, coverage_file, normal_names)
     items = _split_cnv(items, seq2c_calls_file, read_mapping_file, coverage_file)
     return items
@@ -72,7 +67,10 @@ def run(items):
 def prep_seq2c_bed(data):
     """Selecting the bed file, cleaning, and properly annotating for Seq2C
     """
-    bed_file = regions.get_sv_bed(data)
+    if dd.get_background_cnv_reference(data, "seq2c"):
+        bed_file = _background_to_bed(dd.get_background_cnv_reference(data, "seq2c"), data)
+    else:
+        bed_file = regions.get_sv_bed(data)
     if bed_file:
         bed_file = bedutils.clean_file(bed_file, data, prefix="svregions-")
     else:
@@ -103,6 +101,26 @@ def prep_seq2c_bed(data):
 
     return ready_file
 
+def _background_to_bed(back_file, data):
+    """Convert a seq2c background file with calls into BED regions for coverage.
+
+    seq2c background files are a concatenation of mapping and sample_coverages from
+    potentially multiple samples. We use the coverage information from the first
+    sample to translate into BED.
+    """
+    out_file = os.path.join(utils.safe_makedir(os.path.join(dd.get_work_dir(data), "bedprep")),
+                            "%s-regions.bed" % utils.splitext_plus(os.path.basename(back_file))[0])
+    if not utils.file_exists(out_file):
+        with file_transaction(data, out_file) as tx_out_file:
+            with open(back_file) as in_handle:
+                with open(tx_out_file, "w") as out_handle:
+                    sample = in_handle.readline().split("\t")[0]
+                    for line in in_handle:
+                        if line.startswith(sample) and len(line.split()) >= 5:
+                            _, gene, chrom, start, end = line.split()[:5]
+                            out_handle.write("%s\n" % ("\t".join([chrom, str(int(start) - 1), end, gene])))
+    return out_file
+
 def _get_seq2c_options(data):
     """Get adjustable, through resources, or default options for seq2c.
     """
@@ -135,13 +153,14 @@ def _call_cnv(items, work_dir, read_mapping_file, coverage_file, control_sample_
         with file_transaction(items[0], output_fpath) as tx_out_file:
             export = utils.local_path_export()
             cmd = ("{export} {cov2lr} -a {cov2lr_opt} {read_mapping_file} {coverage_file} | " +
-                   "{lr2gene} {lr2gene_opt} > {output_fpath}")
+                   "{lr2gene} {lr2gene_opt} > {tx_out_file}")
             do.run(cmd.format(**locals()), "Seq2C CNV calling")
     return output_fpath
 
 def _split_cnv(items, calls_fpath, read_mapping_file, coverage_file):
     out_items = []
     for item in items:
+        cur_sv = {"variantcaller": "seq2c", "coverage": tz.get_in(["depth", "bins", "seq2c"], item)}
         if not get_paired_phenotype(item) == "normal":
             sample_name = dd.get_sample_name(item)
             work_dir = _sv_workdir(item)
@@ -153,14 +172,14 @@ def _split_cnv(items, calls_fpath, read_mapping_file, coverage_file):
                         for l in inp:
                             if l.split("\t")[0] == sample_name:
                                 out.write(l)
-            for i, sv in enumerate(item["sv"]):
-                if sv["variantcaller"] == "seq2c":
-                    item["sv"][i]["calls"] = out_fname
-                    item["sv"][i]["vrn_file"] = to_vcf(out_fname, item)
-                    item["sv"][i]["read_mapping"] = read_mapping_file
-                    item["sv"][i]["calls_all"] = calls_fpath
-                    item["sv"][i]["coverage_all"] = coverage_file
-                    break
+            cur_sv.update({"calls": out_fname, "vrn_file": to_vcf(out_fname, item),
+                           "read_mapping": read_mapping_file, "calls_all": calls_fpath,
+                           "coverage_all": coverage_file})
+        if "sv" not in item:
+            item["sv"] = []
+        assert "seq2c" not in [x["variantcaller"] for x in item["sv"]], \
+            "Do not expect existing seq2c variant output: %s" % (dd.get_sample_name(item))
+        item["sv"].append(cur_sv)
         out_items.append(item)
     return out_items
 
@@ -268,24 +287,31 @@ def _depth_to_seq2cov(input_fpath, output_fpath, sample_name):
                 out.write('\t'.join(fs) + '\n')
     return output_fpath
 
-def _combine_coverages(items, work_dir):
+def _combine_coverages(items, work_dir, input_backs=None):
     """Combine coverage cnns calculated for individual inputs into single file.
+
+    Optionally moves over pre-calculated coverage samples from a background file.
     """
     out_file = os.path.join(work_dir, "sample_coverages.txt")
     if not utils.file_exists(out_file):
         with file_transaction(items[0], out_file) as tx_out_file:
             with open(tx_out_file, 'w') as out_f:
                 for data in items:
-                    svouts = [x for x in data["sv"] if x["variantcaller"] == "seq2c"]
-                    cfiles = list(set([os.path.basename(x["coverage"]) for x in svouts]))
-                    assert len(cfiles) == 1, (dd.get_sample_name(data), cfiles)
-                    cov_file = svouts[0]["coverage"]
+                    cov_file = tz.get_in(["depth", "bins", "seq2c"], data)
                     with open(cov_file) as cov_f:
                         out_f.write(cov_f.read())
+                if input_backs:
+                    for input_back in input_backs:
+                        with open(input_back) as in_handle:
+                            for line in in_handle:
+                                if len(line.split()) >= 4:
+                                    out_f.write(line)
     return out_file
 
-def _calculate_mapping_reads(items, work_dir):
+def _calculate_mapping_reads(items, work_dir, input_backs=None):
     """Calculate read counts from samtools idxstats for each sample.
+
+    Optionally moves over pre-calculated mapping counts from a background file.
     """
     out_file = os.path.join(work_dir, "mapping_reads.txt")
     if not utils.file_exists(out_file):
@@ -293,13 +319,19 @@ def _calculate_mapping_reads(items, work_dir):
         for data in items:
             count = 0
             for line in subprocess.check_output([
-                "samtools", "idxstats", dd.get_align_bam(data)]).split("\n"):
+                "samtools", "idxstats", dd.get_align_bam(data)]).decode().split("\n"):
                 if line.strip():
                     count += int(line.split("\t")[2])
             lines.append("%s\t%s" % (dd.get_sample_name(data), count))
         with file_transaction(items[0], out_file) as tx_out_file:
             with open(tx_out_file, "w") as out_handle:
-                out_handle.write("\n".join(lines))
+                out_handle.write("\n".join(lines) + "\n")
+                if input_backs:
+                    for input_back in input_backs:
+                        with open(input_back) as in_handle:
+                            for line in in_handle:
+                                if len(line.split()) == 2:
+                                    out_handle.write(line)
     return out_file
 
 # def _count_mapped_reads(data, work_dir, bed_file, bam_file):
