@@ -640,7 +640,7 @@ def _add_batch(x, sample):
     """
     added = False
     for batch in sorted(dd.get_batches(sample) or [], key=len, reverse=True):
-        if batch and os.path.basename(x["path"]).startswith("%s-" % batch):
+        if batch and os.path.basename(x["path"]).startswith(("%s-" % batch, "%s.vcf" % batch)):
             x["batch"] = batch
             added = True
             break
@@ -753,6 +753,8 @@ def _get_files_project(sample, upload_config):
                         "type": "rownames"})
             out.append({"path": count_file + ".colnames",
                         "type": "colnames"})
+            out.append({"path": count_file + ".metadata",
+                        "type": "metadata"})
             umi_file = os.path.splitext(count_file)[0] + "-dupes.mtx"
             if utils.file_exists(umi_file):
                 out.append({"path": umi_file,
@@ -761,6 +763,13 @@ def _get_files_project(sample, upload_config):
                             "type": "rownames"})
                 out.append({"path": umi_file + ".colnames",
                             "type": "colnames"})
+            if dd.get_combined_histogram(sample):
+                out.append({"path": dd.get_combined_histogram(sample),
+                            "type": "txt"})
+            rda = os.path.join(os.path.dirname(count_file), "se.rda")
+            if utils.file_exists(rda):
+                out.append({"path": rda,
+                            "type": "rda"})
         else:
             out.append({"path": dd.get_combined_counts(sample)})
     if dd.get_annotated_combined_counts(sample):
