@@ -1,5 +1,6 @@
 """Helpful utilities for building analysis pipelines.
 """
+import glob
 import gzip
 import os
 import tempfile
@@ -197,7 +198,18 @@ def chdir(new_dir):
 
     http://lucentbeing.com/blog/context-managers-and-the-with-statement-in-python/
     """
-    cur_dir = os.getcwd()
+    # On busy filesystems can have issues accessing main directory. Allow retries
+    num_tries = 0
+    max_tries = 5
+    cur_dir = None
+    while cur_dir is None:
+        try:
+            cur_dir = os.getcwd()
+        except OSError:
+            if num_tries > max_tries:
+                raise
+            num_tries += 1
+            time.sleep(2)
     safe_makedir(new_dir)
     os.chdir(new_dir)
     try:
@@ -346,8 +358,8 @@ def symlink_plus(orig, new):
         if os.path.exists(orig + ext) and (not os.path.lexists(new + ext) or not os.path.exists(new + ext)):
             with chdir(os.path.dirname(new)):
                 remove_safe(new + ext)
-               # Work around symlink issues on some filesystems. Randomly
-               # fail to symlink.
+                # Work around symlink issues on some filesystems. Randomly
+                # fail to symlink.
                 try:
                     os.symlink(os.path.relpath(orig + ext), os.path.basename(new + ext))
                 except OSError:
@@ -361,14 +373,17 @@ def symlink_plus(orig, new):
             with chdir(os.path.dirname(new_noext)):
                 os.symlink(os.path.relpath(orig_noext + sub_ext), os.path.basename(new_noext + sub_ext))
 
-def open_gzipsafe(f):
-    if f.endswith(".gz"):
+def open_gzipsafe(f, is_gz=False):
+    if f.endswith(".gz") or is_gz:
         if six.PY3:
-            return gzip.open(f, "rt")
+            return gzip.open(f, "rt", encoding="utf-8", errors="ignore")
         else:
             return gzip.open(f)
     else:
-        return open(f)
+        if six.PY3:
+            return open(f, encoding="utf-8", errors="ignore")
+        else:
+            return open(f)
 
 def is_empty_gzipsafe(f):
     h = open_gzipsafe(f)
@@ -462,7 +477,7 @@ def merge_config_files(fnames):
     """
     def _load_yaml(fname):
         with open(fname) as in_handle:
-            config = yaml.load(in_handle)
+            config = yaml.safe_load(in_handle)
         return config
     out = _load_yaml(fnames[0])
     for fname in fnames[1:]:
@@ -639,7 +654,10 @@ def which(program, env=None):
             exe_file = os.path.join(path, program)
             if is_exe(exe_file):
                 return exe_file
-
+    for path in get_all_conda_bins():
+        exe_file = os.path.join(path, program)
+        if is_exe(exe_file):
+            return exe_file
     return None
 
 def reservoir_sample(stream, num_items, item_parser=lambda x: x):
@@ -747,10 +765,10 @@ def clear_java_home():
 def get_java_clprep(cmd=None):
     """Correctly prep command line for java commands, setting PATH and unsetting JAVA_HOME.
     """
-    return "%s && export PATH=%s:$PATH" % (clear_java_home(), get_java_binpath(cmd))
+    return "%s && export PATH=%s:\"$PATH\"" % (clear_java_home(), get_java_binpath(cmd))
 
 def get_R_exports():
-    return "unset R_HOME && unset R_LIBS && export PATH=%s:$PATH" % (os.path.dirname(Rscript_cmd()))
+    return "unset R_HOME && unset R_LIBS && export PATH=%s:\"$PATH\"" % (os.path.dirname(Rscript_cmd()))
 
 def perl_cmd():
     """Retrieve path to locally installed conda Perl or first in PATH.
@@ -765,7 +783,7 @@ def get_perl_exports(tmpdir=None):
     """Environmental exports to use conda installed perl.
     """
     perl_path = os.path.dirname(perl_cmd())
-    out = "unset PERL5LIB && export PATH=%s:$PATH" % (perl_path)
+    out = "unset PERL5LIB && export PATH=%s:\"$PATH\"" % (perl_path)
     if tmpdir:
         out += " && export TMPDIR=%s" % (tmpdir)
     return out
@@ -788,6 +806,15 @@ def append_path(bin, path, at_start=True):
 def get_bcbio_bin():
     return os.path.dirname(os.path.realpath(sys.executable))
 
+def get_all_conda_bins():
+    """Retrieve all possible conda bin directories, including environments.
+    """
+    bcbio_bin = get_bcbio_bin()
+    conda_dir = os.path.dirname(bcbio_bin)
+    if os.path.join("anaconda", "envs") in conda_dir:
+        conda_dir = os.path.join(conda_dir[:conda_dir.rfind(os.path.join("anaconda", "envs"))], "anaconda")
+    return [bcbio_bin] + list(glob.glob(os.path.join(conda_dir, "envs", "*", "bin")))
+
 def get_program_python(cmd):
     """Get the full path to a python version linked to the command.
 
@@ -796,17 +823,50 @@ def get_program_python(cmd):
     """
     full_cmd = os.path.realpath(which(cmd))
     cmd_python = os.path.join(os.path.dirname(full_cmd), "python")
+    env_python = None
+    if "envs" in cmd_python:
+        parts = cmd_python.split(os.sep)
+        env_python = os.path.join(os.sep.join(parts[:parts.index("envs") + 2]), "bin", "python")
     if os.path.exists(cmd_python):
         return cmd_python
+    elif env_python and os.path.exists(env_python):
+        return env_python
     else:
-        return sys.executable
+        return os.path.realpath(sys.executable)
 
-def local_path_export(at_start=True):
-    path = get_bcbio_bin()
+def local_path_export(at_start=True, env_cmd=None):
+    """Retrieve paths to local install, also including environment paths if env_cmd included.
+    """
+    paths = [get_bcbio_bin()]
+    if env_cmd:
+        env_path = os.path.dirname(get_program_python(env_cmd))
+        if env_path not in paths:
+            paths.insert(0, env_path)
     if at_start:
-        return "export PATH=%s:$PATH && " % (path)
+        return "export PATH=%s:\"$PATH\" && " % (":".join(paths))
     else:
-        return "export PATH=$PATH:%s && " % (path)
+        return "export PATH=\"$PATH\":%s && " % (":".join(paths))
+
+def locale_export():
+    """Exports for dealing with Click-based programs and ASCII/Unicode errors.
+
+    RuntimeError: Click will abort further execution because Python 3 was
+    configured to use ASCII as encoding for the environment.
+    Consult https://click.palletsprojects.com/en/7.x/python3/ for mitigation steps.
+
+    Looks up available locales on the system to find an appropriate one to pick,
+    defaulting to C.UTF-8 which is globally available on newer systems.
+    """
+    locale_to_use = "C.UTF-8"
+    try:
+        locales = subprocess.check_output(["locale", "-a"]).decode(errors="ignore").split("\n")
+    except subprocess.CalledProcessError:
+        locales = []
+    for locale in locales:
+        if locale.lower().endswith(("utf-8", "utf8")):
+            locale_to_use = locale
+            break
+    return "export LC_ALL=%s && export LANG=%s && " % (locale_to_use, locale_to_use)
 
 def java_freetype_fix():
     """Provide workaround for issues FreeType library symbols.
