@@ -78,7 +78,7 @@ def prep_vep_cache(dbkey, ref_file, tooldir=None, config=None):
     resource_file = os.path.join(os.path.dirname(ref_file), "%s-resources.yaml" % dbkey)
     if os.path.exists(resource_file):
         with open(resource_file) as in_handle:
-            resources = yaml.load(in_handle)
+            resources = yaml.safe_load(in_handle)
         ensembl_name = tz.get_in(["aliases", "ensembl"], resources)
         symlink_dir = _special_dbkey_maps(dbkey, ref_file)
         if ensembl_name and ensembl_name.find("_vep_") == -1:
@@ -150,7 +150,7 @@ def run_vep(in_file, data):
                         config_args += plugin_args
                     config_args += ["--sift", "b", "--polyphen", "b"]
                     if hgvs_compatible:
-                        config_args += ["--hgvs", "--shift_hgvs", "1"]
+                        config_args += ["--hgvsg","--hgvs", "--shift_hgvs", "1"]
                 if (dd.get_effects_transcripts(data).startswith("canonical")
                       or tz.get_in(("config", "algorithm", "clinical_reporting"), data)):
                     config_args += ["--pick_allele"]
@@ -234,7 +234,7 @@ def _get_G2P(data):
     A VEP plugin that uses G2P allelic requirements to assess variants in genes
     for potential phenotype involvement.
     """
-    G2P_file = tz.get_in(("genome_resources", "variation", "genotype2phenotype"), data)
+    G2P_file = os.path.realpath(tz.get_in(("genome_resources", "variation", "genotype2phenotype"), data))
     args = ["--plugin", "G2P,file:%s" % (G2P_file)]
     if G2P_file:
         return args
@@ -351,7 +351,7 @@ def _get_snpeff_cmd(cmd_name, datadir, data, out_file):
     memory = " ".join(jvm_opts)
     snpeff = config_utils.get_program("snpEff", data["config"])
     java_args = "-Djava.io.tmpdir=%s" % utils.safe_makedir(os.path.join(os.path.dirname(out_file), "tmp"))
-    export = "unset JAVA_HOME && export PATH=%s:$PATH && " % (utils.get_java_binpath())
+    export = "unset JAVA_HOME && export PATH=%s:\"$PATH\" && " % (utils.get_java_binpath())
     cmd = "{export} {snpeff} {memory} {java_args} {cmd_name} -dataDir {datadir}"
     return cmd.format(**locals())
 
