@@ -5,7 +5,6 @@ import os
 import six
 import sys
 import numpy as np
-from cyvcf2 import VCF, Writer
 
 from bcbio import utils
 from bcbio.log import logger
@@ -16,6 +15,8 @@ from bcbio.pipeline import datadict as dd
 from bcbio.provenance import do
 from bcbio.variation import bamprep, bedutils, joint, ploidy, vcfutils
 
+cyvcf2 = utils.LazyImport("cyvcf2")
+
 def run(align_bams, items, ref_file, assoc_files, region, out_file):
     """Run strelka2 variant calling, either paired tumor/normal or germline calling.
 
@@ -123,7 +124,8 @@ def _get_ploidy(regions, items, base_file):
 
 def _configure_germline(align_bams, items, ref_file, region, out_file, tx_work_dir):
     utils.safe_makedir(tx_work_dir)
-    cmd = [sys.executable, os.path.realpath(utils.which("configureStrelkaGermlineWorkflow.py"))]
+    cmd = [utils.get_program_python("configureStrelkaGermlineWorkflow.py"),
+           os.path.realpath(utils.which("configureStrelkaGermlineWorkflow.py"))]
     cur_bed = get_region_bed(region, items, out_file)
     cmd += ["--referenceFasta=%s" % ref_file,
             "--callRegions=%s" % cur_bed,
@@ -149,7 +151,8 @@ def _run_germline(align_bams, items, ref_file, assoc_files, region, out_file, wo
 
 def _configure_somatic(paired, ref_file, region, out_file, tx_work_dir):
     utils.safe_makedir(tx_work_dir)
-    cmd = [sys.executable, os.path.realpath(utils.which("configureStrelkaSomaticWorkflow.py"))]
+    cmd = [utils.get_program_python("configureStrelkaSomaticWorkflow.py"),
+           os.path.realpath(utils.which("configureStrelkaSomaticWorkflow.py"))]
     cur_bed = get_region_bed(region, [paired.tumor_data, paired.normal_data], out_file)
     cmd += ["--referenceFasta=%s" % ref_file,
             "--callRegions=%s" % cur_bed,
@@ -228,7 +231,7 @@ def _af_annotate_and_filter(paired, items, in_file, out_file):
     ungz_out_file = "%s.vcf" % utils.splitext_plus(out_file)[0]
     if not utils.file_exists(ungz_out_file) and not utils.file_exists(ungz_out_file + ".gz"):
         with file_transaction(data, ungz_out_file) as tx_out_file:
-            vcf = VCF(in_file)
+            vcf = cyvcf2.VCF(in_file)
             vcf.add_format_to_header({
                 'ID': 'AF',
                 'Description': 'Allele frequency, as calculated in bcbio: AD/DP (germline), <ALT>U/DP (somatic snps), '
@@ -241,7 +244,7 @@ def _af_annotate_and_filter(paired, items, in_file, out_file):
                     '(configured in bcbio as min_allele_fraction)'
                     if utils.get_in(data["config"], ("algorithm", "min_allele_fraction"))
                     else '(default threshold in bcbio; override with min_allele_fraction in the algorithm section)')})
-            w = Writer(tx_out_file, vcf)
+            w = cyvcf2.Writer(tx_out_file, vcf)
             tumor_index = vcf.samples.index(data['description'])
             for rec in vcf:
                 if paired:  # somatic?
@@ -252,7 +255,7 @@ def _af_annotate_and_filter(paired, items, in_file, out_file):
                     dp = rec.format('DP')[:,0]
                 elif rec.format("AD") is not None:  # germline?
                     alt_counts = rec.format('AD')[:,1:]  # AD=REF,ALT1,ALT2,...
-                    dp = np.sum(rec.format('AD')[:,0:], axis=1)
+                    dp = np.sum(rec.format('AD')[:,0:], axis=1)[:, None]
                 else: # germline gVCF record
                     alt_counts, dp = (None, None)
                 if dp is not None:
@@ -318,7 +321,8 @@ def _run_workflow(data, workflow_file, work_dir):
     """Run Strelka2 analysis inside prepared workflow directory.
     """
     utils.remove_safe(os.path.join(work_dir, "workspace"))
-    cmd = [sys.executable, workflow_file, "-m", "local", "-j", dd.get_num_cores(data), "--quiet"]
+    cmd = [utils.get_program_python("configureStrelkaGermlineWorkflow.py"),
+           workflow_file, "-m", "local", "-j", dd.get_num_cores(data), "--quiet"]
     do.run(cmd, "Run Strelka2: %s" % dd.get_sample_name(data))
     utils.remove_safe(os.path.join(work_dir, "workspace"))
 
