@@ -390,6 +390,11 @@ def _run_concat_variant_files_gatk4(input_file_list, out_file, config):
             config = utils.deepish_copy(config)
             if "gatk4" in dd.get_tools_off({"config": config}):
                 config["algorithm"]["tools_off"].remove("gatk4")
+            # Allow specification of verbosity in the unique style this tool uses
+            resources = config_utils.get_resources("gatk", config)
+            opts = [str(x) for x in resources.get("options", [])]
+            if "--verbosity" in opts:
+                params += ["--VERBOSITY:%s" % opts[opts.index("--verbosity") + 1]]
             broad_runner = broad.runner_from_config(config)
             broad_runner.run_gatk(params)
     return out_file
@@ -435,8 +440,12 @@ def _fix_gatk_header(exist_files, out_file, config):
         header_file = "%s-header.vcf" % utils.splitext_plus(tx_out_file)[0]
         do.run("zgrep ^# %s > %s"
                 % (replace_file, header_file), "Prepare header file for merging")
-        do.run("%s && picard FixVcfHeader HEADER=%s INPUT=%s OUTPUT=%s" %
-               (utils.get_java_clprep(), header_file, base_file, base_fix_file),
+        resources = config_utils.get_resources("picard", config)
+        ropts = []
+        if "options" in resources:
+            ropts += [str(x) for x in resources.get("options", [])]
+        do.run("%s && picard FixVcfHeader HEADER=%s INPUT=%s OUTPUT=%s %s" %
+               (utils.get_java_clprep(), header_file, base_file, base_fix_file, " ".join(ropts)),
                "Reheader initial VCF file in merge")
     bgzip_and_index(base_fix_file, config)
     return [base_fix_file] + [x for (c, x) in exist_files[1:]]
